@@ -1,9 +1,9 @@
 /*****************************************************************************
- * Copyright (C) 1997-2019 by Dimitri van Heesch.
+ * Copyright (C) 1997-2025 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -14,6 +14,7 @@
 #include <algorithm>
 
 #include "arguments.h"
+#include "util.h"
 
 /*! the argument list is documented if one of its
  *  arguments is documented
@@ -30,3 +31,9 @@ bool ArgumentList::hasTemplateDocumentation() const
 {
   return std::any_of(begin(),end(),[](const Argument &a){ return a.hasTemplateDocumentation(); });
 }
+
+/*! Sets the trailing return type for a method */
+void ArgumentList::setTrailingReturnType(const QCString &s)
+{
+  m_trailingReturnType = removeRedundantWhiteSpace(s);
+}
